2D examples
===========
These examples require raw data which are automatically
downloaded from the source repository by the script
:download:`example_helper.py <../examples/example_helper.py>`.
Please make sure that this script is present in the example
script folder.

.. fancy_include:: backprop_from_mie_2d_cylinder_offcenter.py

.. fancy_include:: backprop_from_mie_2d_weights_angles.py

.. fancy_include:: backprop_from_mie_2d_incomplete_coverage.py

.. fancy_include:: backprop_from_fdtd_2d.py

